
\subsection{\texttt{default}}
\blindtext

\begin{lstlisting}
\hvFloat{figure}{\includegraphics{frose}}{\capShortText}{}
\end{lstlisting}

\hvFloat{figure}{\includegraphics{frose}}{\capShortText}{}

\blindtext

\begin{lstlisting}
\hvFloat{figure}{\includegraphics{frose}}{\capLongText}{}
\end{lstlisting}

\hvFloat{figure}{\includegraphics{frose}}{\capLongText}{}

\blindtext

\NewColumn



%----------------------top-----------------------------------
\subsection{\texttt{capPos=top}}

\begin{lstlisting}
\hvFloat[capPos=top]{figure}{\includegraphics{frose}}{\capShortText}{}
\end{lstlisting}

\hvFloat[capPos=top]{figure}{\includegraphics{frose}}{\capShortText}{}

\blindtext

\begin{lstlisting}
\hvFloat[capPos=top]{figure}{\includegraphics{frose}}{\capLongText}{}
\end{lstlisting}

\hvFloat[capPos=top]{figure}{\includegraphics{frose}}{\capLongText}{}

\blindtext

\NewColumn

%----------------------before-----------------------------------
\subsection{\texttt{capPos=before}, same as \texttt{capPos=left}}

\begin{lstlisting}
\hvFloat[capPos=before]{figure}{\includegraphics{frose}}{\capShortText}{}
\end{lstlisting}

\hvFloat[capPos=before]{figure}{\includegraphics{frose}}{\capShortText}{}

\blindtext

\begin{lstlisting}
\hvFloat[capPos=before]{figure}{\includegraphics{frose}}{\capLongText}{}
\end{lstlisting}

\hvFloat[capPos=before]{figure}{\includegraphics{frose}}{\capLongText}{}

\blindtext
\NewColumn

%----------------------after-----------------------------------
\subsection{\texttt{capPos=after}, same as \texttt{capPos=right}}

\begin{lstlisting}
\hvFloat[capPos=after]{figure}{\includegraphics{frose}}{\capShortText}{}
\end{lstlisting}

\hvFloat[capPos=after]{figure}{\includegraphics{frose}}{\capShortText}{}

\blindtext

\begin{lstlisting}
\hvFloat[capPos=after]{figure}{\includegraphics{frose}}{\capLongText}{}
\end{lstlisting}

\hvFloat[capPos=after]{figure}{\includegraphics{frose}}{\capLongText}{}

\blindtext

\NewColumn

%----------------------inner-----------------------------------
\subsection{\texttt{capPos=inner}}

\begin{lstlisting}
\hvFloat[capPos=inner]{figure}{\includegraphics{frose}}{\capShortText}{}
\end{lstlisting}

\hvFloat[capPos=inner]{figure}{\includegraphics{frose}}{\capShortText}{}

\blindtext

\begin{lstlisting}
\hvFloat[capPos=inner]{figure}{\includegraphics{frose}}{\capLongText}{}
\end{lstlisting}

\hvFloat[capPos=inner]{figure}{\includegraphics{frose}}{\capLongText}{}

\blindtext

\NewColumn


%----------------------outer-----------------------------------
\subsection{\texttt{capPos=outer}}

\begin{lstlisting}
\hvFloat[capPos=outer]{figure}{\includegraphics{frose}}{\capShortText}{}
\end{lstlisting}

\hvFloat[capPos=outer]{figure}{\includegraphics{frose}}{\capShortText}{}

\blindtext

\begin{lstlisting}
\hvFloat[capPos=outer]{figure}{\includegraphics{frose}}{\capLongText}{}
\end{lstlisting}

\hvFloat[capPos=outer]{figure}{\includegraphics{frose}}{\capLongText}{}

\blindtext

\NewColumn

